@@ -1,16 +1,17 @@
 #![allow(dead_code)]
 
-use anyhow::{anyhow, Result};
+use anyhow::{anyhow, Context, Result};
 use rustc_hir::{
   intravisit::{self, NestedVisitorMap, Visitor},
   itemlikevisit::ItemLikeVisitor,
-  Body, BodyId, Expr, Stmt,
+  BodyId, Expr,
 };
 use rustc_middle::{hir::map::Map, ty::TyCtxt};
 use rustc_span::{FileName, RealFileName, SourceFile, Span};
+
 use std::{path::Path, rc::Rc};
 
-pub fn qpath_to_span(tcx: TyCtxt, qpath: String) -> Option<Span> {
+pub fn qpath_to_span(tcx: TyCtxt, qpath: String) -> Result<Span> {
   struct Finder<'tcx> {
     tcx: TyCtxt<'tcx>,
     qpath: String,
@@ -32,7 +33,7 @@ pub fn qpath_to_span(tcx: TyCtxt, qpath: String) -> Option<Span> {
         .tcx
         .def_path(local_def_id.to_def_id())
         .to_string_no_crate_verbose();
-      if &function_path[2..] == self.qpath {
+      if function_path[2..] == self.qpath {
         self.span = Some(self.tcx.hir().span(id.hir_id));
       }
     }
@@ -60,7 +61,9 @@ pub fn qpath_to_span(tcx: TyCtxt, qpath: String) -> Option<Span> {
     span: None,
   };
   tcx.hir().krate().visit_all_item_likes(&mut finder);
-  return finder.span;
+  finder
+    .span
+    .with_context(|| format!("No function with qpath {}", finder.qpath))
 }
 
 pub fn path_to_source_file<'tcx>(
@@ -80,60 +83,10 @@ pub fn path_to_source_file<'tcx>(
         false
       }
     })
-    .map(|file| file.clone())
+    .cloned()
     .ok_or_else(|| anyhow!("Could not find file {} out of files {:#?}", path, **files))
 }
 
-pub struct HirSpanner {
-  spans: Vec<Span>,
-}
-
-impl HirSpanner {
-  pub fn new(body: &Body) -> Self {
-    HirSpanner {
-      spans: Self::collect_spans(body),
-    }
-  }
-
-  fn collect_spans(body: &Body) -> Vec<Span> {
-    struct Collector {
-      spans: Vec<Span>,
-    }
-
-    impl Visitor<'hir> for Collector {
-      type Map = Map<'hir>;
-
-      fn nested_visit_map(&mut self) -> NestedVisitorMap<Self::Map> {
-        NestedVisitorMap::None
-      }
-
-      fn visit_expr(&mut self, expr: &Expr) {
-        self.spans.push(expr.span);
-        intravisit::walk_expr(self, expr);
-      }
-
-      fn visit_stmt(&mut self, stmt: &Stmt) {
-        self.spans.push(stmt.span);
-        intravisit::walk_stmt(self, stmt);
-      }
-    }
-
-    let mut collector = Collector { spans: Vec::new() };
-    intravisit::walk_body(&mut collector, body);
-
-    collector.spans
-  }
-
-  pub fn find_enclosing_hir_span(&self, span: Span) -> Option<Span> {
-    self
-      .spans
-      .iter()
-      .filter(|hir_span| hir_span.contains(span))
-      .min_by_key(|hir_span| hir_span.hi() - hir_span.lo())
-      .cloned()
-  }
-}
-
 pub fn expr_to_string(expr: &Expr) -> String {
   rustc_hir_pretty::to_string(rustc_hir_pretty::NO_ANN, |s| s.print_expr(expr))
 }
